# Service Configuration Lib

[![Build Status](https://travis-ci.org/Yelp/service_configuration_lib.svg?branch=master)](https://travis-ci.org/Yelp/service_configuration_lib)

service_configuration_lib is a Python interface to Yelp's SOA architecture.

WARNING: service_configuration_lib has been running in production at Yelp for more than a year, and
has a number of "Yelpisms" still lingering in the codebase. We have made efforts
to excise them, but there are bound to be lingering issues. Please help us by
opening an issue or better yet a pull request.

You can learn more about Yelp's SOA architecture by watching
[this](https://t.co/5khQ5KHDWL) video.

## Installation

From source:

    python setup.py install

From pypi:

    pip install service-configuration-lib


## License

service_configuration_lib is licensed under the Apache License, Version 2.0: http://www.apache.org/licenses/LICENSE-2.0
